#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tagstream-conduit
version:              0.5.6
visibility:           public
id:                   tagstream-conduit-0.5.6-4PDYSz1ywSCEk5qm6tZUCX
key:                  tagstream-conduit-0.5.6-4PDYSz1ywSCEk5qm6tZUCX
license:              BSD-3-Clause
maintainer:           yi.codeplayer@gmail.com
author:               yihuang
homepage:             http://github.com/yihuang/tagstream-conduit
synopsis:             streamlined html tag parser
description:
    Tag-stream is a library for parsing HTML//XML to a token stream.
    It can parse unstructured and malformed HTML from the web.
    It also provides an Enumeratee which can parse streamline html, which means it consumes constant memory.
    You can start from the `tests/Tests.hs` module to see what it can do.

category:             Web, Conduit
abi:                  0172f7aa8932aaf0a11695a9414988c2
exposed:              True
exposed-modules:
    Text.HTML.TagStream Text.HTML.TagStream.ByteString
    Text.HTML.TagStream.Entities Text.HTML.TagStream.Text
    Text.HTML.TagStream.Types Text.HTML.TagStream.Utils

import-dirs:          /usr/lib/ghc-9.6.6/site-local/tagstream-conduit-0.5.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tagstream-conduit-0.5.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tagstream-conduit-0.5.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tagstream-conduit
hs-libraries:         HStagstream-conduit-0.5.6-4PDYSz1ywSCEk5qm6tZUCX
depends:
    attoparsec-0.14.4-Lt8CzeQB1UCKNIPCgGeJTD base-4.18.2.1
    blaze-builder-0.4.4.1-7DIK9vMysGNGOGHtPzm22s bytestring-0.11.5.3
    case-insensitive-1.2.1.0-Ewy0DH0xZp6BX0SdeD8DKD
    conduit-1.3.6.1-5N1D7XReUYC7Q0FFK7LvDS
    conduit-extra-1.3.8-4QLRWNABAYIHYZwgT1lJOW
    data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG
    resourcet-1.3.0-NkgSS2nOUY5UPO0Rt6LWs text-2.0.2
    transformers-0.6.1.0 xml-conduit-1.9.1.4-E6JvmROA7PV7RBeKdYgzXb

haddock-interfaces:
    /usr/share/doc/haskell-tagstream-conduit/html/tagstream-conduit.haddock

haddock-html:         /usr/share/doc/haskell-tagstream-conduit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

